@@ -1,7 +1,7 @@
 /*
  * fsp-parser.c
  *
- * Copyright (C) 2010-2012 Mario Sanchez Prada
+ * Copyright (C) 2010-2014 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -22,12 +22,7 @@
 
 #include "fsp-error.h"
 
-#ifdef HAVE_LIBSOUP_GNOME
-#include <libsoup/soup-gnome.h>
-#else
 #include <libsoup/soup.h>
-#endif
-
 #include <libxml/parser.h>
 #include <libxml/xpath.h>
 
