@@ -1,7 +1,7 @@
 /*
  * fsp-session.h
  *
- * Copyright (C) 2010-2012 Mario Sanchez Prada
+ * Copyright (C) 2010-2014 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -65,12 +65,13 @@ FspSession *
 fsp_session_new                         (const gchar *api_key,
                                          const gchar *secret,
                                          const gchar *token);
+void
+fsp_session_set_default_proxy           (FspSession *self,
+                                         gboolean enabled);
 gboolean
-fsp_session_set_http_proxy              (FspSession *self,
-                                         gboolean use_gnome_proxy,
+fsp_session_set_custom_proxy            (FspSession *self,
                                          const char *host, const char *port,
                                          const char *username, const char *password);
-
 const gchar *
 fsp_session_get_api_key                 (FspSession *self);
 
