@@ -1,7 +1,7 @@
 /*
  * frogr-config.h -- Configuration system for Frogr.
  *
- * Copyright (C) 2009-2012 Mario Sanchez Prada
+ * Copyright (C) 2009-2014 Mario Sanchez Prada
  *           (C) 2009 Adrian Perez
  * Authors:
  *   Adrian Perez <aperez@igalia.com>
@@ -154,10 +154,6 @@ void frogr_config_set_use_proxy (FrogrConfig *self, gboolean value);
 
 gboolean frogr_config_get_use_proxy (FrogrConfig *self);
 
-void frogr_config_set_use_gnome_proxy (FrogrConfig *self, gboolean value);
-
-gboolean frogr_config_get_use_gnome_proxy (FrogrConfig *self);
-
 void frogr_config_set_proxy_host (FrogrConfig *self, const gchar *host);
 
 const gchar *frogr_config_get_proxy_host (FrogrConfig *self);
