@@ -37,7 +37,7 @@
 #include <glib/gi18n.h>
 
 /* Paths relative to the icons dir */
-#define MAIN_VIEW_ICON(_s) "/hicolor/" _s "/apps/frogr.png"
+#define ICON_PATH_FORMAT_STRING "%s/hicolor/%s/apps/frogr.png"
 
 #define MINIMUM_WINDOW_WIDTH 840
 #define MINIMUM_WINDOW_HEIGHT 600
@@ -137,6 +137,9 @@ enum {
 /* Prototypes */
 
 static void _initialize_ui (FrogrMainView *self);
+static void _initialize_toolbar (GtkWidget *toolbar);
+static gboolean _initialize_app_menu (FrogrMainView *self);
+
 static GtkToolItem *_create_toolbar_item (const gchar *action_name, const gchar *icon_name, const gchar *label, const gchar *tooltip_text);
 static gboolean _maybe_show_auth_dialog_on_idle (FrogrMainView *self);
 
@@ -279,6 +282,10 @@ static void _update_ui (FrogrMainView *self);
 
 /* Private API */
 
+static  const gchar *icon_sizes[] = {
+  "128x128", "64x64", "48x48", "32x32", "24x24", "16x16"
+};
+
 static GActionEntry app_entries[] = {
   { ACTION_AUTHORIZE, _on_menu_item_activated, NULL, NULL, NULL },
   { ACTION_LOGIN_AS, _on_radio_menu_item_activated, "s", "''", _on_radio_menu_item_changed },
@@ -320,41 +327,25 @@ _initialize_ui (FrogrMainView *self)
   GtkWidget *progress_bar;
   GtkWidget *progress_label;
   GtkWidget *toolbar;
-  GtkToolItem *toolbar_item;
   GMenuModel *ctxt_menu_model;
   const gchar *icons_path = NULL;
   gchar *full_path = NULL;
   GList *icons = NULL;
   GAction *action = NULL;
   GVariant *action_parameter = NULL;
+  gint i = 0;
 
   priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
 
   /* Provide a default icon list in several sizes */
+
   icons_path = frogr_util_get_icons_dir ();
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("128x128"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
-
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("64x64"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
-
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("48x48"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
-
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("32x32"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
-
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("24x24"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
-
-  full_path = g_strdup_printf ("%s/" MAIN_VIEW_ICON("16x16"), icons_path);
-  icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
-  g_free (full_path);
+  for (i = 0; i < G_N_ELEMENTS (icon_sizes); ++i)
+    {
+      full_path = g_strdup_printf (ICON_PATH_FORMAT_STRING, icons_path, icon_sizes[i]);
+      icons = g_list_prepend (icons, gdk_pixbuf_new_from_file (full_path, NULL));
+      g_free (full_path);
+    }
 
   gtk_window_set_default_icon_list (icons);
   g_list_foreach (icons, (GFunc) g_object_unref, NULL);
@@ -398,22 +389,7 @@ _initialize_ui (FrogrMainView *self)
 
   /* Toolbar */
   toolbar = GTK_WIDGET (gtk_builder_get_object (builder, "toolbar"));
-  toolbar_item = _create_toolbar_item ("win.open-project", "gtk-open", _("Open"), _("Open Existing Project"));
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 0);
-  toolbar_item = _create_toolbar_item ("win.save-project", "gtk-save", _("Save"), _("Save Current Project"));
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 1);
-  toolbar_item = gtk_separator_tool_item_new ();
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 2);
-  toolbar_item = _create_toolbar_item ("win.add-pictures", "gtk-add", _("Add"), _("Add Elements"));
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 3);
-  toolbar_item = _create_toolbar_item ("win.remove-pictures", "gtk-remove", _("Remove"), _("Remove Elements"));
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 4);
-  toolbar_item = gtk_separator_tool_item_new ();
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 5);
-  toolbar_item = _create_toolbar_item ("win.upload-all", "gtk-go-up", _("Upload"), _("Upload All"));
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_item, 6);
-  gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
-                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+  _initialize_toolbar (toolbar);
 
   icon_view = GTK_WIDGET (gtk_builder_get_object (builder, "icon_view"));
   priv->icon_view = icon_view;
@@ -448,9 +424,6 @@ _initialize_ui (FrogrMainView *self)
 
   /* Initialize extra widgets */
 
-  /* Populate accounts submenu from model */
-  _populate_accounts_submenu (self);
-
   /* Create contextual menus for right-clicks */
   full_path = g_strdup_printf ("%s/" UI_CONTEXT_MENU_FILE, frogr_util_get_app_data_dir ());
   gtk_builder_add_from_file (builder, full_path, NULL);
@@ -542,10 +515,6 @@ _initialize_ui (FrogrMainView *self)
 
   gtk_builder_connect_signals (builder, self);
 
-#ifdef PLATFORM_MAC
-  _tweak_app_menu_for_mac (self);
-#endif
-
   /* Update window title */
   _update_window_title (self, FALSE);
 
@@ -553,9 +522,50 @@ _initialize_ui (FrogrMainView *self)
   _update_ui (FROGR_MAIN_VIEW (self));
 
   /* Show the auth dialog, if needed, on idle */
-  g_idle_add ((GSourceFunc) _maybe_show_auth_dialog_on_idle, self);
+  gdk_threads_add_idle ((GSourceFunc) _maybe_show_auth_dialog_on_idle, self);
 
-  gtk_widget_show_all (GTK_WIDGET (self));
+#ifdef PLATFORM_MAC
+  /* FIXME: This is an UGLY hack that helps avoiding the race condition
+     but probably does not prevent it completely. Needs to check it more
+     carefully and fix it properly in the future when I have more time. */
+  gdk_threads_add_timeout (1000, (GSourceFunc) _initialize_app_menu, self);
+#else
+  _initialize_app_menu (self);
+#endif
+
+  gtk_widget_show (GTK_WIDGET (self));
+}
+
+static void _initialize_toolbar (GtkWidget *toolbar)
+{
+  GtkToolItem *toolbar_items[7];
+  gint i;
+
+  toolbar_items[0] = _create_toolbar_item ("win.open-project", "gtk-open", _("Open"), _("Open Existing Project"));
+  toolbar_items[1] = _create_toolbar_item ("win.save-project", "gtk-save", _("Save"), _("Save Current Project"));
+  toolbar_items[2] = gtk_separator_tool_item_new ();
+  toolbar_items[3] = _create_toolbar_item ("win.add-pictures", "gtk-add", _("Add"), _("Add Elements"));
+  toolbar_items[4] = _create_toolbar_item ("win.remove-pictures", "gtk-remove", _("Remove"), _("Remove Elements"));
+  toolbar_items[5] = gtk_separator_tool_item_new ();
+  toolbar_items[6] = _create_toolbar_item ("win.upload-all", "gtk-go-up", _("Upload"), _("Upload All"));
+
+  for (i = 0; i < G_N_ELEMENTS (toolbar_items); ++i)
+    gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_items[i], i);
+
+  gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
+                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+}
+
+static gboolean
+_initialize_app_menu (FrogrMainView *self)
+{
+  _populate_accounts_submenu (self);
+
+#ifdef PLATFORM_MAC
+  _tweak_app_menu_for_mac (self);
+#endif
+
+  return FALSE;
 }
 
 static GtkToolItem *
@@ -565,9 +575,12 @@ _create_toolbar_item (const gchar *action_name, const gchar *icon_name, const gc
   GtkToolItem *item = NULL;
 
   widget = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_SMALL_TOOLBAR);
+  gtk_widget_show (widget);
+
   item = gtk_tool_button_new (widget, label);
   gtk_tool_item_set_tooltip_text (item, tooltip_text);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (item), action_name);
+  gtk_widget_show (GTK_WIDGET (item));
 
   return item;
 }
@@ -1008,6 +1021,7 @@ _handle_selection_for_button_event_and_path (FrogrMainView *mainview,
   gboolean using_primary_key = event->state & GDK_PRIMARY_MASK;
   gboolean using_shift_key = event->state & GDK_SHIFT_MASK;
   gboolean is_single_click = event->type == GDK_BUTTON_PRESS;
+  gboolean is_double_click = event->type == GDK_2BUTTON_PRESS;
   gboolean is_primary_btn = event->button == 1;
   gboolean path_selected = gtk_icon_view_path_is_selected (GTK_ICON_VIEW (priv->icon_view), path);
 
@@ -1021,7 +1035,8 @@ _handle_selection_for_button_event_and_path (FrogrMainView *mainview,
     {
       gint n_selected_pictures = priv->n_selected_pictures;
 
-      _deselect_all_pictures (mainview);
+      if (!is_double_click)
+        _deselect_all_pictures (mainview);
 
       /* We will just select the pointed element if it's not selected yet
          or if it is, but it belongs to a multiple selection previously done */
