@@ -1,7 +1,7 @@
 /*
  * main.c -- Main file and initialization
  *
- * Copyright (C) 2009-2012 Mario Sanchez Prada
+ * Copyright (C) 2009-2014 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -25,15 +25,18 @@
 
 #include <config.h>
 #include <glib/gi18n.h>
+#ifdef HAVE_GSTREAMER
 #include <gst/gst.h>
+#endif
 #include <libxml/parser.h>
 
 int
 main (int argc, char **argv)
 {
   FrogrController *controller = NULL;
-  GError *error = NULL;
   int status;
+#ifdef HAVE_GSTREAMER
+  GError *error = NULL;
 
   /* Initialize gstreamer before using any other GLib function */
   gst_init_check (&argc, &argv, &error);
@@ -42,6 +45,7 @@ main (int argc, char **argv)
       DEBUG ("Gstreamer could not be initialized: %s", error->message);
       g_error_free (error);
     }
+#endif
 
   /* Initialize libxml2 library */
   xmlInitParser ();
